@@ -1,8 +1,8 @@
 from . import process
 from . import file
-from . import gui
+from . import simulate
 from .version import __version__
 
-from .file.log import Logger
-logger = Logger()
+#from .file.log import Logger
+#logger = Logger()
 
